@@ -17,7 +17,7 @@ class DelimitEndpoints:
         :return: status
         """
         data_filter = f"Afasemployeenumber={employee_id},Startdate={start_date},Enddate={end_date}"
-        response = self.base_class.delete_data(uri='MasterActionDel', data_filter=data_filter)
+        response = self.base_class.delete_data(uri='MasterActionDel', filter=data_filter)
         response.raise_for_status()
         return response
 
@@ -30,7 +30,7 @@ class DelimitEndpoints:
         :return: status
         """
         data_filter = f"OrgUnitID={org_unit},Startdate={start_date},Enddate={end_date}"
-        response = self.base_class.delete_data(uri='OrgUnitDel', data_filter=data_filter)
+        response = self.base_class.delete_data(uri='OrgUnitDel', filter=data_filter)
         response.raise_for_status()
         return response
 
@@ -43,7 +43,7 @@ class DelimitEndpoints:
         :return: status
         """
         data_filter = f"PositionID={position_id},Startdate={start_date},Enddate={end_date}"
-        response = self.base_class.delete_data(uri="PositionDel", data_filter=data_filter)
+        response = self.base_class.delete_data(uri="PositionDel", filter=data_filter)
         response.raise_for_status()
         return response
 
@@ -57,6 +57,6 @@ class DelimitEndpoints:
         :return: status
         """
         data_filter = f"PositionID={position_id},Startdate={start_date},Enddate={end_date},WorkcenterID={workcenter}"
-        response = self.base_class.delete_data(uri="WorkcenterDel", data_filter=data_filter)
+        response = self.base_class.delete_data(uri="WorkcenterDel", filter=data_filter)
         response.raise_for_status()
         return response
