@@ -1,10 +1,13 @@
-from salure_helpers.sap import Base
+from salure_helpers.sap.base_functions import BaseFunctions
+import requests
+import warnings
+import json
+from typing import Union, List
 
 
-class PostEndpoints(SalureConnect):
+class PostEndpoints:
     def __init__(self, label: str, data_dir: str, certificate_file: str = None, key_file: str = None, debug: bool = False):
-        super().__init__()
-        self.sap = Base(label, data_dir, certificate_file, key_file, debug)
+        self.base_class = BaseFunctions(label=label, data_dir=data_dir, certificate_file=certificate_file, key_file=key_file, debug=debug)
         self.data_dir = data_dir
         self.debug = debug
 
@@ -72,7 +75,7 @@ class PostEndpoints(SalureConnect):
 
         # Update the request body with update fields
         base_body.update(fields_to_update)
-        response = self.sap.post_data(uri='MasterActionPost/*', data=base_body, return_key='Employeenumber')
+        response = self.base_class.post_data(uri='MasterActionPost/*', data=base_body, return_key='Employeenumber')
         return response
 
     def post_personal_data(self, data: dict, overload_fields: dict = None):
@@ -113,7 +116,7 @@ class PostEndpoints(SalureConnect):
 
         # Update the request body with update fields
         base_body.update(fields_to_update)
-        response = self.sap.post_data(uri='PersonalDataPost/*', data=base_body, return_key='Employeenumber')
+        response = self.base_class.post_data(uri='PersonalDataPost/*', data=base_body, return_key='Employeenumber')
         return response
 
     def post_communication(self, data: dict, overload_fields: dict = None):
@@ -147,7 +150,7 @@ class PostEndpoints(SalureConnect):
         # Update the request body with update fields
         base_body.update(fields_to_update)
 
-        response = self.sap.post_data(uri='CommunicationsPost/*', data=base_body, return_key='UserId')
+        response = self.base_class.post_data(uri='CommunicationsPost/*', data=base_body, return_key='UserId')
         return response
 
     def post_organisational_unit(self, data: dict, overload_fields: dict = None):
@@ -180,7 +183,7 @@ class PostEndpoints(SalureConnect):
         # Update the request body with update fields
         base_body.update(fields_to_update)
 
-        response = self.sap.post_data(uri='OrgUnitPost', data=base_body, return_key='OrgUnitID')
+        response = self.base_class.post_data(uri='OrgUnitPost/*', data=base_body, return_key='OrgUnitID')
         return response
 
     def post_position(self, data: dict, overload_fields: dict = None):
@@ -214,7 +217,7 @@ class PostEndpoints(SalureConnect):
         # Update the request body with update fields
         base_body.update(fields_to_update)
 
-        response = self.sap.post_data(uri='PositionPost', data=base_body, return_key='OrgUnitID')
+        response = self.base_class.post_data(uri='PositionPost/*', data=base_body, return_key='OrgUnitID')
         return response
 
     def post_workcenter(self, data: dict, overload_fields: dict = None):
@@ -242,7 +245,6 @@ class PostEndpoints(SalureConnect):
         # Update the request body with update fields
         base_body.update(fields_to_update)
 
-        response = self.sap.post_data(uri='WorkcenterPost', data=data, return_key='WorkcenterID')
+        response = self.base_class.post_data(uri='WorkcenterPost/*', data=data, return_key='WorkcenterID')
         return response
 
-
